# Changelog

## 1.0.0 (2026-01-08)

### Features

* add `list_palettes()` utility function ([51e34df](https://github.com/jolars/qualpal-py/commit/51e34dfea4414f0654f0d2ada27eb712ecadce98))
* add color conversions ([24be558](https://github.com/jolars/qualpal-py/commit/24be558cc4818f97222847d8f8a7d1f978b015d3))
* add color distance api ([1d0426e](https://github.com/jolars/qualpal-py/commit/1d0426e6a2cb679ac507a44a5f844c6d36286e5c))
* add cvd simulation and support in generation ([0f5123d](https://github.com/jolars/qualpal-py/commit/0f5123d74eab578c51c7fa76bc9221b00a3d2c71))
* add exporting ([11bcb8f](https://github.com/jolars/qualpal-py/commit/11bcb8f0914cff32edacf481947afc76f2cb5e72))
* add Palette class ([4f76b2a](https://github.com/jolars/qualpal-py/commit/4f76b2a31958fdf362ecba5d80991d60ac489da0))
* add palette generation ([00f32d3](https://github.com/jolars/qualpal-py/commit/00f32d3ef97d460e43a55153076df652397dfa1a))
* add plotting support ([6cc95c9](https://github.com/jolars/qualpal-py/commit/6cc95c975c13046df61063658e895aff207f64f7))
* add Qualpal class ([31a2464](https://github.com/jolars/qualpal-py/commit/31a24645e86268aaf61207fc8a3f5d6159480abf))
* add qualpal library ([d01e47f](https://github.com/jolars/qualpal-py/commit/d01e47f5251328f7aa8e69a9e4db9308a456f559))
* add rich display for html ([f95f0e7](https://github.com/jolars/qualpal-py/commit/f95f0e7ff8eae3df4fdffc8c1c73f33789646e7b))
* implement `Color` class ([0bedec3](https://github.com/jolars/qualpal-py/commit/0bedec338f51a6b593fd478f373617080a2e3b20))
* support palette analysis ([dc66077](https://github.com/jolars/qualpal-py/commit/dc660778c4ed3f68ea4631fa1898259690aead04))

### Bug Fixes

* correcty import c++ library ([72f4ecf](https://github.com/jolars/qualpal-py/commit/72f4ecf67c9020c45f07cbe419b0ddae1a47d271))
* disable OpenMP on MSVC ([6e5eb09](https://github.com/jolars/qualpal-py/commit/6e5eb095bad256bc6cbf3d10fbbeb71f7de49ec5))
* don't instantiate the class in linking ([e7db6be](https://github.com/jolars/qualpal-py/commit/e7db6bea0479c94b485a19a1792c54e6273de996))
* refactor openmp setup ([0cff380](https://github.com/jolars/qualpal-py/commit/0cff380bf26b2c39d0ecaa461f9bbdbb4b0b8fdf))
* reinstate math definitions for MSVC ([3dd70df](https://github.com/jolars/qualpal-py/commit/3dd70df21295ae47257102f9d1d6b60d4eef3eeb))
* remove license classifier ([3c151ba](https://github.com/jolars/qualpal-py/commit/3c151ba02ee4a84ac0d1abeef993e802ee706425))
* remove pre-commit yaml fro sdist build ([68efc3d](https://github.com/jolars/qualpal-py/commit/68efc3d6d9e9f40d2b8ba50c6edefb689bbe75e3))
* rename tests properly ([4478234](https://github.com/jolars/qualpal-py/commit/4478234af86edc8576be38aa5936ab82a5be4635))
* update qualpal c++ library to 3.4.0 ([cbfeaaa](https://github.com/jolars/qualpal-py/commit/cbfeaaaefebc1951411e867da3406206397f1d30))
* use `_USE_MATH_DEFINES` on MSVC ([7786b97](https://github.com/jolars/qualpal-py/commit/7786b971ab4f5f6333fbbc4fbe8d9950729f7842))
* use `-fPIC` when building qualpal ([3e6375f](https://github.com/jolars/qualpal-py/commit/3e6375f991eb0915bbc2a473cb470e3e1891bdbc))
* use `find_package()` internally ([3e5a9b8](https://github.com/jolars/qualpal-py/commit/3e5a9b8d79573316a8975dbb2975f2ad7b3f21a2))
* use correct logo path ([04246d8](https://github.com/jolars/qualpal-py/commit/04246d831ebd75aa674dd944057e357b816e275a))
* use github token for release action ([105475e](https://github.com/jolars/qualpal-py/commit/105475e8783572a2039e422613905e99afc82044))
